"use strict";
this.author    = "Zafrusteria";
this.copyright = "© 2024 Zafrusteria.";
this.license   = "Creative Commons: attribution, non-commercial,  CC BY-NC-SA 4.0 sharealike - see readme.txt";
this.version   = "0.6";

this.name = "ShrewsRights_extremist_AI";

this.description = "Set the behaviour of the Anti-shrew extremists";

this.$debug = false;

// AI for Anti-shrews extremists.
// started by looking at https://wiki.alioth.net/index.php/Oolite_PriorityAI_Tutorial#Pirate_AI

this.aiStarted = function  ShrewsRights_AI_aiStarted() {
    // create a new AI controller and assign it to this ship
    let ai = new worldScripts["oolite-libPriorityAI"].PriorityAIController(this.ship);

    // see https://wiki.alioth.net/index.php/Oolite_Javascript_Reference:_PriorityAI_Documentation#Parameters
    if (this.$debug) ai.setParameter("oolite_flag_behaviourLogging", true);

    /*
       Set role as "sr_extremist" as the bad guy ships spawn are of personality "ShrewsRights_antishrew_extremist"
       Personality to the OXP's custom "ShrewsRights_extremist". See ShrewsRights_comms.js
    */
    ai.setCommunicationsRole("sr_extremist");
    ai.setCommunicationsPersonality("ShrewsRights_extremist"); // The 'extremist' part comes from ShrewsRights_comms.js

    ai.setParameter("oolite_flag_neverFleeToWitchspace", true);
    // Add some flashing lights, they want to be seen
    ai.configurationLightsOn();

    // Patrol near the witchpoint if lost contact with player
    ai.setWaypointGenerator(ai.waypointsWitchpointPatrol);


    if (this.ship.primaryRole == "sr_extremist_ts") {
        // As this is TS, avoid using an escape pod until late
        ai.setParameter("oolite_flag_surrendersLate",true);

        // Now make most roles 'like' Tiaras Skeets in Whiskers so they do not
        // attack her when they are populating the system.
        ai.setParameter("oolite_friendlyRoles", ["oolite-pirate-victim", "oolite-pirate-enemy", "oolite-pirate-leader", "oolite-pirate", "oolite-bounty-hunter", "oolite-trader", "oolite-assassin", "oolite-courier", "oolite-police-like", "oolite-police-dislike"]);

    } else if (this.ship.primaryRole == "sr_extremist") {
        // only other bad guys like these guys
        ai.setParameter("oolite_friendlyRoles", ["oolite-pirate", "oolite-bounty-hunter"]);

        // Make extremists chatty, because I can :)
        ai.setParameter("oolite_flag_sendsDistressCalls", true);
        ai.setParameter("oolite_flag_listenForDistressCall", true);
    }

    // add our custom AI so we can use all the AI properties via "this"
    // Taken from gcm-assassinAI.js
//    ai.conditionScannerContainsPlayer = this._conditionScannerContainsPlayer;

    ai.setPriorities([
        {
            label: "** Player nearby?",
            condition: ai.conditionPlayerNearby,
            configuration: ai.configurationAcquirePlayerAsTarget,
            behaviour: ai.behaviourCommenceAttackOnCurrentTarget,
            reconsider: 2,
        },
        {
            label: "** Are we fighting",
            condition: ai.conditionInCombat,
            configuration: ai.configurationAcquireCombatTarget,
            behaviour: ai.behaviourDestroyCurrentTarget,
            reconsider: 5,
        },
        {
            label: "** Patrol witchpoint",
            configuration: ai.configurationSetDestinationToWitchpoint,
            behaviour: ai.behaviourApproachDestination,
            reconsider: 35,
        },
        {
            label: "** Some help here!",
            condition: ai.conditionHasReceivedDistressCall,
            behaviour: ai.behaviourRespondToDistressCall,
            reconsider: 20,
        },
        {
            label: "** Hmm, reconsider",
            behaviour: ai.reconsiderNow,
            reconsider: 30,
        }
    ]);
}

// Allows the AI to scan and find the "player" if they are within scanner range.
// Taken from gcm-assassinAI.js
this._conditionScannerContainsPlayer = function() {
    return this.checkScannerWithPredicate(function(s) {
        return s.isPlayer;
    });
}
